.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bluesky-widgets Documentation
=============================

.. toctree::
   :caption: Tutorials
   :maxdepth: 2

   installation

.. toctree::
   :caption: How-To Guides
   :maxdepth: 2

   examples

.. toctree::
   :caption: Explanations
   :maxdepth: 2

   goals
   design 

.. toctree::
   :caption: Reference
   :maxdepth: 2

   reference
   release-history
   min_versions
